"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseImageExtension = exports.parseShopifyId = exports.isShopifyId = exports.setLastBuildTime = exports.getLastBuildTime = exports.getPluginStatus = exports.createNodeId = void 0;
const pattern = /^gid:\/\/shopify\/(\w+)\/(.+)$/;
function createNodeId(shopifyId, gatsbyApi, { typePrefix = `` }) {
    return gatsbyApi.createNodeId(`${typePrefix}${shopifyId}`);
}
exports.createNodeId = createNodeId;
function getPluginStatus(gatsbyApi) {
    var _a;
    return (((_a = gatsbyApi.store.getState().status.plugins) === null || _a === void 0 ? void 0 : _a[`gatsby-source-shopify`]) || {});
}
exports.getPluginStatus = getPluginStatus;
function getLastBuildTime(gatsbyApi, pluginOptions) {
    const { typePrefix = `` } = pluginOptions;
    const status = getPluginStatus(gatsbyApi);
    return (status[`lastBuildTime${typePrefix}`] &&
        new Date(status[`lastBuildTime${typePrefix}`]));
}
exports.getLastBuildTime = getLastBuildTime;
function setLastBuildTime(gatsbyApi, pluginOptions) {
    const { typePrefix = `` } = pluginOptions;
    const status = getPluginStatus(gatsbyApi);
    gatsbyApi.actions.setPluginStatus(Object.assign(Object.assign({}, status), { [`lastBuildTime${typePrefix}`]: Date.now() }));
}
exports.setLastBuildTime = setLastBuildTime;
function isShopifyId(shopifyId) {
    return pattern.test(shopifyId);
}
exports.isShopifyId = isShopifyId;
function parseShopifyId(shopifyId) {
    return shopifyId.match(pattern) || [];
}
exports.parseShopifyId = parseShopifyId;
function parseImageExtension(url) {
    const basename = url.split(`?`)[0];
    const dot = basename.lastIndexOf(`.`);
    if (dot !== -1) {
        return basename.slice(dot + 1);
    }
    else {
        throw new Error(`Could not parse file extension from Shopify image URL: ${url}`);
    }
}
exports.parseImageExtension = parseImageExtension;
//# sourceMappingURL=helpers.js.map